@@ -4,7 +4,7 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: utils.c,v 1.6 1999/03/06 14:35:17 david Rel $
+/* $Id: utils.c,v 1.6 1999/03/06 14:35:17 david Rel david $
  * $Log: utils.c,v $
  * Revision 1.6  1999/03/06 14:35:17  david
  * Internationalized.
@@ -35,7 +35,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <strings.h>
+#include <string.h>
 
 #include "utils.h"
 #include "config.h"
